@@ -27,7 +27,7 @@
 #include <string.h>
 
 #include <gtk/gtk.h>
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 
 #include <libmissioncontrol/mc-account.h>
 #include <libmissioncontrol/mc-protocol.h>
@@ -60,9 +60,27 @@ account_widget_entry_focus_cb (GtkWidget     *widget,
 		gtk_entry_set_text (GTK_ENTRY (widget), value ? value : "");
 		g_free (value);
 	} else {
+		McProfile   *profile;
+		const gchar *domain = NULL;
+		gchar       *dup_str = NULL;
+
+		profile = mc_account_get_profile (account);
+		if (mc_profile_get_capabilities (profile) &
+		    MC_PROFILE_CAPABILITY_SPLIT_ACCOUNT) {
+			domain = mc_profile_get_default_account_domain (profile);
+		}
+
+		if (domain && !strstr (str, "@") &&
+		    strcmp (param_name, "account") == 0) {
+			DEBUG ("Adding @%s suffix to account", domain);
+			str = dup_str = g_strconcat (str, "@", domain, NULL);
+			gtk_entry_set_text (GTK_ENTRY (widget), str);
+		}
 		DEBUG ("Setting %s to %s", param_name,
 			strstr (param_name, "password") ? "***" : str);
 		mc_account_set_param_string (account, param_name, str);
+		g_free (dup_str);
+		g_object_unref (profile);
 	}
 
 	return FALSE;
@@ -675,7 +693,6 @@ empathy_account_widget_yahoo_new (McAccount *account)
 			"entry_id", "account",
 			"entry_password", "password",
 			"entry_server", "server",
-			"entry_serverjp", "serverjp",
 			"entry_locale", "room-list-locale",
 			"entry_charset", "charset",
 			"spinbutton_port", "port",
