@@ -27,7 +27,7 @@
 
 #include <string.h>
 
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 #include <gdk/gdkkeysyms.h>
 #include <gtk/gtk.h>
 #include <glade/glade.h>
@@ -114,6 +114,19 @@ static guint signals[LAST_SIGNAL];
 
 G_DEFINE_TYPE (EmpathyContactListView, empathy_contact_list_view, GTK_TYPE_TREE_VIEW);
 
+static void
+contact_list_view_tooltip_destroy_cb (GtkWidget              *widget,
+				      EmpathyContactListView *view)
+{
+	EmpathyContactListViewPriv *priv = GET_PRIV (view);
+	
+	if (priv->tooltip_widget) {
+		DEBUG ("Tooltip destroyed");
+		priv->tooltip_widget = NULL;
+		g_object_unref (widget);
+	}
+}
+
 static gboolean
 contact_list_view_query_tooltip_cb (EmpathyContactListView *view,
 				    gint                    x,
@@ -151,9 +164,11 @@ contact_list_view_query_tooltip_cb (EmpathyContactListView *view,
 
 	if (!priv->tooltip_widget) {
 		priv->tooltip_widget = empathy_contact_widget_new (contact,
-			EMPATHY_CONTACT_WIDGET_EDIT_NONE);
-		g_object_add_weak_pointer (G_OBJECT (priv->tooltip_widget),
-					   (gpointer) &priv->tooltip_widget);
+			EMPATHY_CONTACT_WIDGET_FOR_TOOLTIP);
+		g_object_ref (priv->tooltip_widget);
+		g_signal_connect (priv->tooltip_widget, "destroy",
+				  G_CALLBACK (contact_list_view_tooltip_destroy_cb),
+				  view);
 	} else {
 		empathy_contact_widget_set_contact (priv->tooltip_widget,
 						    contact);
@@ -966,6 +981,9 @@ contact_list_view_finalize (GObject *object)
 	if (priv->store) {
 		g_object_unref (priv->store);
 	}
+	if (priv->tooltip_widget) {
+		gtk_widget_destroy (priv->tooltip_widget);
+	}
 
 	G_OBJECT_CLASS (empathy_contact_list_view_parent_class)->finalize (object);
 }
@@ -1187,31 +1205,22 @@ empathy_contact_list_view_get_selected_group (EmpathyContactListView *view)
 
 static gboolean
 contact_list_view_remove_dialog_show (GtkWindow   *parent, 
-				      const gchar *window_title, 
-				      const gchar *text)
+				      const gchar *message, 
+				      const gchar *secondary_text)
 {
-	GtkWidget *dialog, *label, *image, *hbox;
+	GtkWidget *dialog;
 	gboolean res;
 	
-	dialog = gtk_dialog_new_with_buttons (window_title, parent,
-					      GTK_DIALOG_MODAL,
-  					      GTK_STOCK_CANCEL, GTK_RESPONSE_NO,
-					      GTK_STOCK_DELETE, GTK_RESPONSE_YES,
-					      NULL);
-	gtk_dialog_set_has_separator (GTK_DIALOG(dialog), FALSE);
+	dialog = gtk_message_dialog_new (parent, GTK_DIALOG_MODAL,
+					 GTK_MESSAGE_QUESTION, GTK_BUTTONS_NONE,
+					 "%s", message);
+	gtk_dialog_add_buttons (GTK_DIALOG (dialog),
+				GTK_STOCK_CANCEL, GTK_RESPONSE_NO,
+				GTK_STOCK_DELETE, GTK_RESPONSE_YES,
+				NULL);
+	gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+						  "%s", secondary_text);
 	 
-	label = gtk_label_new (text);
-	image = gtk_image_new_from_stock (GTK_STOCK_DIALOG_QUESTION, GTK_ICON_SIZE_DIALOG);
-	 
-	hbox = gtk_hbox_new (FALSE, 5);
-	gtk_container_set_border_width (GTK_CONTAINER (hbox), 5);
-	gtk_box_pack_start_defaults (GTK_BOX (hbox), image);
-	gtk_box_pack_start_defaults (GTK_BOX (hbox), label);	 
-	gtk_box_pack_start_defaults (GTK_BOX(GTK_DIALOG(dialog)->vbox), hbox);
-
-	gtk_widget_show (image);
-	gtk_widget_show (label);
-	gtk_widget_show (hbox);
 	gtk_widget_show (dialog);
 	 
 	res = gtk_dialog_run (GTK_DIALOG (dialog));
