@@ -28,21 +28,17 @@
 #include "empathy-contact-manager.h"
 #include "empathy-contact-list.h"
 #include "empathy-utils.h"
+
+#define DEBUG_FLAG EMPATHY_DEBUG_CONTACT
 #include "empathy-debug.h"
 
-#define GET_PRIV(obj) (G_TYPE_INSTANCE_GET_PRIVATE ((obj), \
-		       EMPATHY_TYPE_CONTACT_MANAGER, EmpathyContactManagerPriv))
-
-#define DEBUG_DOMAIN "ContactManager"
-
-struct _EmpathyContactManagerPriv {
+#define GET_PRIV(obj) EMPATHY_GET_PRIV (obj, EmpathyContactManager)
+typedef struct {
 	GHashTable     *lists;
 	MissionControl *mc;
 	gpointer        token;
-};
+} EmpathyContactManagerPriv;
 
-static void empathy_contact_manager_class_init (EmpathyContactManagerClass *klass);
-static void empathy_contact_manager_init       (EmpathyContactManager      *manager);
 static void contact_manager_iface_init         (EmpathyContactListIface    *iface);
 
 G_DEFINE_TYPE_WITH_CODE (EmpathyContactManager, empathy_contact_manager, G_TYPE_OBJECT,
@@ -121,8 +117,7 @@ contact_manager_destroy_cb (EmpathyTpContactList  *list,
 
 	account = empathy_tp_contact_list_get_account (list);
 
-	empathy_debug (DEBUG_DOMAIN, "Removing account: %s",
-		       mc_account_get_display_name (account));
+	DEBUG ("Removing account: %s", mc_account_get_display_name (account));
 
 	contact_manager_disconnect_foreach (account, list, manager);
 	g_hash_table_remove (priv->lists, account);
@@ -139,8 +134,7 @@ contact_manager_add_account (EmpathyContactManager *manager,
 		return;
 	}
 
-	empathy_debug (DEBUG_DOMAIN, "Adding new account: %s",
-		       mc_account_get_display_name (account));
+	DEBUG ("Adding new account: %s", mc_account_get_display_name (account));
 
 	list = empathy_tp_contact_list_new (account);
 	if (!list) {
@@ -210,11 +204,11 @@ empathy_contact_manager_class_init (EmpathyContactManagerClass *klass)
 static void
 empathy_contact_manager_init (EmpathyContactManager *manager)
 {
-	EmpathyContactManagerPriv *priv;
 	GSList                    *accounts, *l;
+	EmpathyContactManagerPriv *priv = G_TYPE_INSTANCE_GET_PRIVATE (manager,
+		EMPATHY_TYPE_CONTACT_MANAGER, EmpathyContactManagerPriv);
 
-	priv = GET_PRIV (manager);
-
+	manager->priv = priv;
 	priv->lists = g_hash_table_new_full (empathy_account_hash,
 					     empathy_account_equal,
 					     (GDestroyNotify) g_object_unref,
@@ -513,3 +507,19 @@ contact_manager_iface_init (EmpathyContactListIface *iface)
 	iface->remove_group	 = contact_manager_remove_group;
 }
 
+gboolean
+empathy_contact_manager_can_add (EmpathyContactManager *manager,
+				 McAccount             *account)
+{
+	EmpathyContactManagerPriv *priv = GET_PRIV (manager);
+	EmpathyTpContactList      *list;
+	
+	g_return_val_if_fail (EMPATHY_IS_CONTACT_MANAGER (manager), FALSE);
+
+	list = g_hash_table_lookup (priv->lists, account);
+	if (list == NULL)
+		return FALSE;
+
+	return empathy_tp_contact_list_can_add (list);
+}
+
