@@ -28,9 +28,8 @@
 #include <string.h>
 #include <time.h>
 #include <sys/types.h>
-#include <regex.h>
 
-#include <glib/gi18n.h>
+#include <glib/gi18n-lib.h>
 
 #include <libxml/uri.h>
 #include <telepathy-glib/connection.h>
@@ -44,7 +43,29 @@
 #define DEBUG_FLAG EMPATHY_DEBUG_OTHER
 #include "empathy-debug.h"
 
-static void regex_init (void);
+void
+empathy_init (void)
+{
+	static gboolean initialized = FALSE;
+
+	if (initialized)
+		return;
+
+	g_type_init ();
+
+	/* Setup gettext */
+	bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+
+	/* Setup debug output for empathy and telepathy-glib */
+	if (g_getenv ("EMPATHY_TIMING") != NULL) {
+		g_log_set_default_handler (tp_debug_timestamped_log_handler, NULL);
+	}
+	empathy_debug_set_flags (g_getenv ("EMPATHY_DEBUG"));
+	tp_debug_divert_messages (g_getenv ("EMPATHY_LOGFILE"));
+
+	initialized = TRUE;
+}
 
 gchar *
 empathy_substring (const gchar *str,
@@ -54,129 +75,6 @@ empathy_substring (const gchar *str,
 	return g_strndup (str + start, end - start);
 }
 
-/*
- * Regular Expression code to match urls.
- */
-#define APTCHARS  "-A-Za-z0-9,-."
-#define USERCHARS "-A-Za-z0-9"
-#define PASSCHARS "-A-Za-z0-9,?;.:/!%$^*&~\"#'"
-#define HOSTCHARS "-A-Za-z0-9_"
-#define PATHCHARS "-A-Za-z0-9_$.+!*(),;:@&=?/~#%"
-#define SCHEME    "(news:|telnet:|nntp:|file:/|https?:|ftps?:|webcal:)"
-#define USER      "[" USERCHARS "]+(:["PASSCHARS "]+)?"
-#define URLPATH   "/[" PATHCHARS "]*[^]'.}>) \t\r\n,\\\"]"
-
-static regex_t dingus[EMPATHY_REGEX_ALL];
-
-static void
-regex_init (void)
-{
-	static gboolean  inited = FALSE;
-	const gchar     *expression;
-	gint             i;
-
-	if (inited) {
-		return;
-	}
-
-	for (i = 0; i < EMPATHY_REGEX_ALL; i++) {
-		switch (i) {
-		case EMPATHY_REGEX_AS_IS:
-			expression =
-				SCHEME "//(" USER "@)?[" HOSTCHARS ".]+"
-				"(:[0-9]+)?(" URLPATH ")?";
-			break;
-		case EMPATHY_REGEX_BROWSER:
-			expression =
-				"(www|ftp)[" HOSTCHARS "]*\\.[" HOSTCHARS ".]+"
-				"(:[0-9]+)?(" URLPATH ")?";
-			break;
-		case EMPATHY_REGEX_APT:
-			expression =
-				"apt://[" APTCHARS "]*";
-			break;
-		case EMPATHY_REGEX_EMAIL:
-			expression =
-				"(mailto:)?[a-z0-9][a-z0-9._-]*@[a-z0-9]"
-				"[a-z0-9-]*(\\.[a-z0-9][a-z0-9-]*)+";
-			break;
-		case EMPATHY_REGEX_OTHER:
-			expression =
-				"news:[-A-Z\\^_a-z{|}~!\"#$%&'()*+,./0-9;:=?`]+"
-				"@[" HOSTCHARS ".]+(:[0-9]+)?";
-			break;
-		default:
-			/* Silence the compiler. */
-			expression = NULL;
-			continue;
-		}
-
-		memset (&dingus[i], 0, sizeof (regex_t));
-		regcomp (&dingus[i], expression, REG_EXTENDED | REG_ICASE);
-	}
-
-	inited = TRUE;
-}
-
-gint
-empathy_regex_match (EmpathyRegExType  type,
-		    const gchar     *msg,
-		    GArray          *start,
-		    GArray          *end)
-{
-	regmatch_t matches[1];
-	gint       ret = 0;
-	gint       num_matches = 0;
-	gint       offset = 0;
-	gint       i;
-
-	g_return_val_if_fail (type >= 0 || type <= EMPATHY_REGEX_ALL, 0);
-
-	regex_init ();
-
-	while (!ret && type != EMPATHY_REGEX_ALL) {
-		ret = regexec (&dingus[type], msg + offset, 1, matches, 0);
-		if (ret == 0) {
-			gint s;
-
-			num_matches++;
-
-			s = matches[0].rm_so + offset;
-			offset = matches[0].rm_eo + offset;
-
-			g_array_append_val (start, s);
-			g_array_append_val (end, offset);
-		}
-	}
-
-	if (type != EMPATHY_REGEX_ALL) {
-		DEBUG ("Found %d matches for regex type:%d", num_matches, type);
-		return num_matches;
-	}
-
-	/* If EMPATHY_REGEX_ALL then we run ALL regex's on the string. */
-	for (i = 0; i < EMPATHY_REGEX_ALL; i++, ret = 0) {
-		while (!ret) {
-			ret = regexec (&dingus[i], msg + offset, 1, matches, 0);
-			if (ret == 0) {
-				gint s;
-
-				num_matches++;
-
-				s = matches[0].rm_so + offset;
-				offset = matches[0].rm_eo + offset;
-
-				g_array_append_val (start, s);
-				g_array_append_val (end, offset);
-			}
-		}
-	}
-
-	DEBUG ("Found %d matches for ALL regex types", num_matches);
-
-	return num_matches;
-}
-
 gint
 empathy_strcasecmp (const gchar *s1,
 		   const gchar *s2)
