@@ -144,7 +144,7 @@ empathy_chatrooms_window_show (GtkWindow *parent)
 	g_object_add_weak_pointer (G_OBJECT (window->window), (gpointer) &window);
 
 	/* Get the session and chat room manager */
-	window->manager = empathy_chatroom_manager_new ();
+	window->manager = empathy_chatroom_manager_new (NULL);
 
 	g_signal_connect (window->manager, "chatroom-added",
 			  G_CALLBACK (chatrooms_window_chatroom_added_cb),
@@ -413,7 +413,6 @@ chatrooms_window_model_cell_auto_connect_toggled (GtkCellRendererToggle  *cell,
 	enabled = !enabled;
 
 	empathy_chatroom_set_auto_connect (chatroom, enabled);
-	empathy_chatroom_manager_store (window->manager);
 
 	gtk_list_store_set (store, &iter, COL_AUTO_CONNECT, enabled, -1);
 	gtk_tree_path_free (path);
