@@ -619,7 +619,7 @@ main_window_favorite_chatroom_menu_setup (EmpathyMainWindow *window)
 {
 	GList *chatrooms, *l;
 
-	window->chatroom_manager = empathy_chatroom_manager_new ();
+	window->chatroom_manager = empathy_chatroom_manager_new (NULL);
 	chatrooms = empathy_chatroom_manager_get_chatrooms (window->chatroom_manager, NULL);
 	window->room_menu = gtk_menu_item_get_submenu (GTK_MENU_ITEM (window->room));
 
@@ -924,7 +924,7 @@ static void
 main_window_help_contents_cb (GtkWidget         *widget,
 			      EmpathyMainWindow *window)
 {
-	empathy_url_show ("ghelp:empathy");
+	empathy_url_show (widget, "ghelp:empathy");
 }
 
 static gboolean
